@@ -20,9 +20,4 @@
 Universal JSON utilities developed by Linaro
 """
 
-__version__ = (2, 0, 0, "final", 0)
-try:
-    import versiontools
-    __version__ = versiontools.Version.from_tuple(__version__)
-except ImportError:
-    pass
+__version__ = (2, 0, 1, "final", 0)
