@@ -828,9 +828,9 @@ class ValidatorFailureTests(TestWithScenarios, TestCase):
         }),
         ("type_integer_got_float", {
             'schema': '{"type": "integer"}',
-            'data': '1.1',
+            'data': '1.5',
             'raises': ValidationError(
-                "1.1000000000000001 does not match type 'integer'",
+                "1.5 does not match type 'integer'",
                 "Object has incorrect type (expected integer)"),
             'object_expr': 'object',
             'schema_expr': 'schema.type',
@@ -1313,6 +1313,14 @@ class ValidatorSuccessTests(TestWithScenarios, TestCase):
             'schema': '{"type": {"type": "number"}}',
             'data': '5',
         }),
+        ("type_list_with_two_values_got_first_value", {
+            'schema': '{"type": ["number", "string"]}',
+            'data': '1',
+        }),
+        ("type_list_with_two_values_got_second_value", {
+            'schema': '{"type": ["number", "string"]}',
+            'data': '"string"',
+        }),
         ("property_ignored_on_non_objects", {
             'schema': '{"properties": {"foo": {"type": "number"}}}',
             'data': '"foobar"',
